@@ -3,7 +3,7 @@ package Opt::Imistic;
 use strict;
 use warnings;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 package Opt::Imistic::Option {
     use overload
@@ -84,7 +84,7 @@ sub import {
     for my $o ( keys %ARGV ) {
         # All args are arrayrefs now. This implements tm604's suggestion that we assume
         # it's a countable option if it appears several times, but never with a value.
-        $ARGV{$o} = [ scalar @{ $ARGV{$o} } ] unless grep defined, @{ $ARGV{$o} };
+        @{$ARGV{$o}} = scalar @{ $ARGV{$o} } unless grep defined, @{ $ARGV{$o} };
     }
 
     _store('-', $_) for @ARGV;
@@ -188,7 +188,7 @@ All arguments in C<%ARGV> are now represented as array refs, blessed into a
 package that stringifies them to the last instance of that argument and
 boolifies to true. That means that you can always do
 
-    @{$ARGV}{option_name}
+    @{ $ARGV{option_name} }
 
 or
 
